==> huaweicloudsdkaom-3.0.82-py2.py3-none-any.whl: huaweicloudsdkaom/v2/model/list_log_items_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListLogItemsRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'body': 'QueryBodyParam'
    }

    attribute_map = {
        'type': 'type',
        'body': 'body'
    }

    def __init__(self, type=None, body=None):
        """ListLogItemsRequest - a model defined in huaweicloud sdk"""
        
        

        self._type = None
        self._body = None
        self.discriminator = None

        self.type = type
        if body is not None:
            self.body = body

    @property
    def type(self):
        """Gets the type of this ListLogItemsRequest.

        日志接口调用方式,当值为\"querylogs\"时接口功能为查询日志内容。

        :return: The type of this ListLogItemsRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ListLogItemsRequest.

        日志接口调用方式,当值为\"querylogs\"时接口功能为查询日志内容。

        :param type: The type of this ListLogItemsRequest.
        :type: str
        """
        self._type = type

    @property
    def body(self):
        """Gets the body of this ListLogItemsRequest.


        :return: The body of this ListLogItemsRequest.
        :rtype: QueryBodyParam
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ListLogItemsRequest.


        :param body: The body of this ListLogItemsRequest.
        :type: QueryBodyParam
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListLogItemsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkaom-3.0.100-py2.py3-none-any.whl: huaweicloudsdkaom/v2/model/list_log_items_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListLogItemsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'body': 'QueryBodyParam'
    }

    attribute_map = {
        'type': 'type',
        'body': 'body'
    }

    def __init__(self, type=None, body=None):
        """ListLogItemsRequest

        The model defined in huaweicloud sdk

        :param type: 日志接口调用方式,当值为\&quot;querylogs\&quot;时接口功能为查询日志内容。
        :type type: str
        :param body: Body of the ListLogItemsRequest
        :type body: :class:`huaweicloudsdkaom.v2.QueryBodyParam`
        """
        
        

        self._type = None
        self._body = None
        self.discriminator = None

        self.type = type
        if body is not None:
            self.body = body

    @property
    def type(self):
        """Gets the type of this ListLogItemsRequest.

        日志接口调用方式,当值为\"querylogs\"时接口功能为查询日志内容。

        :return: The type of this ListLogItemsRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ListLogItemsRequest.

        日志接口调用方式,当值为\"querylogs\"时接口功能为查询日志内容。

        :param type: The type of this ListLogItemsRequest.
        :type type: str
        """
        self._type = type

    @property
    def body(self):
        """Gets the body of this ListLogItemsRequest.


        :return: The body of this ListLogItemsRequest.
        :rtype: :class:`huaweicloudsdkaom.v2.QueryBodyParam`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ListLogItemsRequest.


        :param body: The body of this ListLogItemsRequest.
        :type body: :class:`huaweicloudsdkaom.v2.QueryBodyParam`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListLogItemsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
